@@ -10,8 +10,8 @@ class ManageFiles():
         config = configparser.ConfigParser()
         config.sections()
         config.read("broker_config.ini")
-        FMS_HOST = config.get('FMSConfig','FMS_HOST') or '10.1.0.5'
-        FMS_PORT = config.get('FMSConfig','FMS_HOST') or '8007'
+        FMS_HOST = config.get('FMSConfig','FMS_HOST')
+        FMS_PORT = config.get('FMSConfig','FMS_PORT')
         self.fms_host = FMS_HOST
         self.fms_port = FMS_PORT
         self.fms_url = f"{self.fms_host}:{self.fms_port}"
