@@ -4,17 +4,26 @@ import pika.exceptions
 import time
 import os
 import logging
+import configparser
+
 RABBIT_USER = os.getenv('RABBIT_USER') or 'admin'
 RABBIT_PASSWORD = os.getenv('RABBIT_PASSWORD') or 'admin'
 RABBIT_HOST = os.getenv('RABBIT_HOST') or '10.1.0.5'
 RABBIT_PORT = os.getenv('RABBIT_PORT') or '5672'
 
 logging.basicConfig(level=logging.WARNING, format='%(asctime)s - %(levelname)s - %(message)s', datefmt='%d-%b-%y %H:%M:%S')
+logging.getLogger("pika").setLevel(logging.ERROR)
 
 class consumer_class(): 
 
 
     def __init__(self, service_name, handler):
+        config = configparser.ConfigParser()
+        config.sections()
+        config.read("broker_config.ini")
+        host = config.get('FMSConfig','FMS_HOST')
+        port = config.get('FMSConfig','FMS_HOST')
+
         EXCHANGE_NAME = os.getenv('EXCHANGE_NAME') or 'pre_production'
         NEW_JOBS_ROUTING_KEY = os.getenv('NEW_JOBS_ROUTING_KEY') or 'dispatcher.job.ready_for_'
         SUCCESSFUL_JOB_ROUTING_KEY = os.getenv('SUCCESSFUL_JOB_ROUTING_KEY') or '.job.complete'
